.. _reweighting_api:

Reweighting-based ensembles
================================

.. automodule:: imbalanced_ensemble.ensemble.reweighting
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.ensemble.reweighting

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   AdaCostClassifier
   AdaUBoostClassifier
   AsymBoostClassifier